@@ -1,8 +1,13 @@
 import logging
 import datacompy
+from PIL import Image
 from .encry import md5
+from io import BytesIO
+from typing import Union
 from dictdiffer import diff
 from pandas import DataFrame
+from WeTest.util import path
+from pixelmatch.contrib.PIL import pixelmatch
 from jsonschema import validate, draft7_format_checker
 from jsonschema.exceptions import SchemaError, ValidationError
 
@@ -42,6 +47,26 @@ def campare_file(source: str, target: str) -> bool:
     return md5(source, "file") == md5(target, "file")
 
 
+def campre_image(
+    source: Union[str, BytesIO], target: Union[str, BytesIO], output: str, threshold: float = 0.1, includeAA=True, **kwargs
+) -> bool:
+
+    source = Image.open(source)
+    target = Image.open(target)
+    diff = Image.new("RGBA", source.size)
+
+    pixels = pixelmatch(source, target, diff, threshold=threshold, includeAA=includeAA, **kwargs)
+
+    is_match = True
+    if pixels > 0:
+        is_match = False
+
+        logging.info(f"Not match, see {output} for details")
+        diff.save(output)
+
+    return is_match
+
+
 def campare_schema(json: dict, schema: dict) -> bool:
 
     try:
